diff --git a/packages/cli/src/ui/auth/AuthDialog.tsx b/packages/cli/src/ui/auth/AuthDialog.tsx
index 7af7cb9b1c..3342fb6d21 100644
--- a/packages/cli/src/ui/auth/AuthDialog.tsx
+++ b/packages/cli/src/ui/auth/AuthDialog.tsx
@@ -154,7 +154,9 @@ Logging in with Google... Please restart Gemini CLI to continue.
padding={1}
width="100%"
>
- Get started
+
+ Get started
+
How would you like to authenticate for this project?
diff --git a/packages/cli/src/ui/components/EditorSettingsDialog.tsx b/packages/cli/src/ui/components/EditorSettingsDialog.tsx
index e5bccdfc74..9ed601e72f 100644
--- a/packages/cli/src/ui/components/EditorSettingsDialog.tsx
+++ b/packages/cli/src/ui/components/EditorSettingsDialog.tsx
@@ -154,7 +154,9 @@ export function EditorSettingsDialog({
- Editor Preference
+
+ Editor Preference
+
These editors are currently supported. Please note that some editors
diff --git a/packages/cli/src/ui/components/StatsDisplay.tsx b/packages/cli/src/ui/components/StatsDisplay.tsx
index f40d055ad3..8c7bacd7ab 100644
--- a/packages/cli/src/ui/components/StatsDisplay.tsx
+++ b/packages/cli/src/ui/components/StatsDisplay.tsx
@@ -187,7 +187,9 @@ export const StatsDisplay: React.FC = ({
if (title) {
return theme.ui.gradient && theme.ui.gradient.length > 0 ? (
- {title}
+
+ {title}
+
) : (
diff --git a/packages/cli/src/ui/components/ThemeDialog.tsx b/packages/cli/src/ui/components/ThemeDialog.tsx
index c4bc64c302..497ba1c654 100644
--- a/packages/cli/src/ui/components/ThemeDialog.tsx
+++ b/packages/cli/src/ui/components/ThemeDialog.tsx
@@ -215,7 +215,9 @@ export function ThemeDialog({
{/* Right Column: Preview */}
- Preview
+
+ Preview
+
{/* Get the Theme object for the highlighted theme, fall back to default if not found */}
{(() => {
const previewTheme =
diff --git a/packages/cli/src/ui/components/messages/ToolMessage.tsx b/packages/cli/src/ui/components/messages/ToolMessage.tsx
index 99822ece15..f77a14870f 100644
--- a/packages/cli/src/ui/components/messages/ToolMessage.tsx
+++ b/packages/cli/src/ui/components/messages/ToolMessage.tsx
@@ -112,7 +112,9 @@ export const ToolMessage: React.FC = ({
) : typeof resultDisplay === 'string' && !renderOutputAsMarkdown ? (
- {resultDisplay}
+
+ {resultDisplay}
+
) : typeof resultDisplay === 'object' &&
diff --git a/packages/cli/src/ui/utils/MarkdownDisplay.tsx b/packages/cli/src/ui/utils/MarkdownDisplay.tsx
index 42ea164805..2baea99884 100644
--- a/packages/cli/src/ui/utils/MarkdownDisplay.tsx
+++ b/packages/cli/src/ui/utils/MarkdownDisplay.tsx
@@ -188,7 +188,7 @@ const MarkdownDisplayInternal: React.FC = ({
break;
case 3:
headerNode = (
-
+
);
@@ -386,10 +386,10 @@ const RenderListItemInternal: React.FC = ({
flexDirection="row"
>
- {prefix}
+ {prefix}
-
+
diff --git a/packages/cli/src/ui/utils/CodeColorizer.tsx b/packages/cli/src/ui/utils/CodeColorizer.tsx
index e06e199a5e..644248fd05 100644
--- a/packages/cli/src/ui/utils/CodeColorizer.tsx
+++ b/packages/cli/src/ui/utils/CodeColorizer.tsx
@@ -31,8 +31,9 @@ function renderHastNode(
inheritedColor: string | undefined,
): React.ReactNode {
if (node.type === 'text') {
- // Use the color passed down from parent element, if any
- return {node.value};
+ // Use the color passed down from parent element, or the theme's default.
+ const color = inheritedColor || theme.defaultColor;
+ return {node.value};
}
// Handle Element Nodes: Determine color and pass it down, don't wrap